"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getExitCodeOnError = exports.isNodeErrnoError = exports.readFileAsync = exports.getReadmePath = exports.getCoveragePath = void 0;
const fs_1 = __importDefault(require("fs"));
const arguments_1 = require("./arguments");
const getCoveragePath = (path) => {
    let coveragePath = path;
    const argPath = (0, arguments_1.getArgumentValue)('coverageDir');
    if (argPath) {
        coveragePath = `${argPath}/coverage-summary.json`;
    }
    return coveragePath;
};
exports.getCoveragePath = getCoveragePath;
const getReadmePath = (path) => {
    let readmePath = path;
    const argPath = (0, arguments_1.getArgumentValue)('readmeDir');
    if (argPath) {
        readmePath = `${argPath}/README.md`;
    }
    return readmePath;
};
exports.getReadmePath = getReadmePath;
const readFileAsync = async (path, encode) => {
    return new Promise((resolve, reject) => {
        fs_1.default.readFile(path, encode, (err, data) => {
            if (err)
                reject(`File not found at: ${path}`);
            resolve(data);
        });
    });
};
exports.readFileAsync = readFileAsync;
/**
 * Asserts that the given `error` was created by Node internals.
 * @param error The error object.
 * @returns `true` if given error object is a NodeJS error.
 */
const isNodeErrnoError = (error) => error instanceof Error && 'code' in error;
exports.isNodeErrnoError = isNodeErrnoError;
/**
 * Handles optional exitCode on eventual application throw.
 * @returns `number` for chosen exit code or undefined
 */
const getExitCodeOnError = () => {
    const argExitCode = +(0, arguments_1.getArgumentValue)('exitCode');
    return argExitCode && !isNaN(argExitCode) ? argExitCode : undefined;
};
exports.getExitCodeOnError = getExitCodeOnError;
//# sourceMappingURL=helpers.js.map